==> quantlib_1.12.orig.tar.gz: QuantLib-1.12/ql/methods/finitedifferences/fdtypedefs.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file fdtypedefs.hpp
    \brief default choices for template instantiations
*/

#ifndef quantlib_fd_typedefs_hpp
#define quantlib_fd_typedefs_hpp

#include <ql/methods/finitedifferences/cranknicolson.hpp>
#include <ql/methods/finitedifferences/parallelevolver.hpp>

namespace QuantLib {

    //! default choice for finite-difference model
    typedef FiniteDifferenceModel<
                    CrankNicolson<TridiagonalOperator>  >
                                  StandardFiniteDifferenceModel;

    //! default choice for parallel finite-difference model
    typedef FiniteDifferenceModel<ParallelEvolver<
                    CrankNicolson<TridiagonalOperator> > >
                                  StandardSystemFiniteDifferenceModel;

    //! default choice for step condition
    typedef StepCondition<Array> StandardStepCondition;
    typedef CurveDependentStepCondition<Array> StandardCurveDependentStepCondition;

}


#endif

==> quantlib_1.21.orig.tar.gz: QuantLib-1.21/ql/methods/finitedifferences/fdtypedefs.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file fdtypedefs.hpp
    \brief default choices for template instantiations
*/

#ifndef quantlib_fd_typedefs_hpp
#define quantlib_fd_typedefs_hpp

#include <ql/methods/finitedifferences/cranknicolson.hpp>
#include <ql/methods/finitedifferences/parallelevolver.hpp>

namespace QuantLib {

    //! default choice for finite-difference model
    typedef FiniteDifferenceModel<
                    CrankNicolson<TridiagonalOperator>  >
                                  StandardFiniteDifferenceModel;

    //! default choice for parallel finite-difference model
    typedef FiniteDifferenceModel<ParallelEvolver<
                    CrankNicolson<TridiagonalOperator> > >
                                  StandardSystemFiniteDifferenceModel;

    //! default choice for step condition
    typedef StepCondition<Array> StandardStepCondition;

#if defined(__GNUC__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif
#if defined(__clang__)
#pragma clang diagnostic push
#pragma clang diagnostic ignored "-Wdeprecated-declarations"
#endif
#if defined(QL_PATCH_MSVC)
#pragma warning(push)
#pragma warning(disable:4996)
#endif

    /*! \deprecated Inherit from StandardStepCondition directly.
                    Deprecated in version 1.19.
    */
    QL_DEPRECATED
    typedef CurveDependentStepCondition<Array> StandardCurveDependentStepCondition;

#if defined(QL_PATCH_MSVC)
#pragma warning(pop)
#endif
#if defined(__clang__)
#pragma clang diagnostic pop
#endif
#if defined(__GNUC__)
#pragma GCC diagnostic pop
#endif

}


#endif
